@@ -5,11 +5,14 @@ from media_platform.service.media_platform_request import MediaPlatformRequest
 
 
 class CloseStreamRequest(MediaPlatformRequest):
-    def __init__(self, authenticated_http_client: AuthenticatedHTTPClient, base_url: str):
+    def __init__(self, authenticated_http_client: AuthenticatedHTTPClient, base_url: str, stream_id: str = None,
+                 version: str = None, abort: bool = False):
         super().__init__(authenticated_http_client, 'DELETE', base_url + '/live/streams/', None)
 
-        self.stream_id = None
-        self.version = None
+        self.stream_id = stream_id
+        self.version = version
+        self.abort = abort
+
         self._url = base_url + '/live/streams/'
 
     def set_stream_id(self, stream_id: str) -> CloseStreamRequest:
@@ -20,9 +23,25 @@ class CloseStreamRequest(MediaPlatformRequest):
         self.version = version
         return self
 
+    def set_abort(self, abort: bool) -> CloseStreamRequest:
+        self.abort = abort
+        return self
+
     def execute(self):
         self.url = self._url + self.stream_id
-        if self.version:
-            self.url += '?version=' + self.version
+        query_string = self._query_string()
+
+        if query_string:
+            self.url += '?' + query_string
 
         return super().execute()
+
+    def _query_string(self) -> str:
+        query_string = ''
+        if self.version:
+            query_string += 'version=' + self.version
+
+        if self.abort:
+            query_string += 'abort=True'
+
+        return query_string
